# Yorumsepeti
##### A package for fetching restaurant reviews from yemeksepeti.com.

## Installation

To install via pip, run;

```
pip install yorumsepeti
```

Yorumsepeti requires [Selenium](https://selenium-python.readthedocs.io/index.html) to run.

## Example Dataset

Example Yorumsepeti dataset can be found in [this](https://www.kaggle.com/dgknrsln/yorumsepeti) Kaggle page.


## License

MIT License
